@@ -11,6 +11,7 @@
  * Author: Damian Waradzyn
  */
 
+#include "network.h"
 #include <zlib.h>
 
 #define CLOUDMADE_BUILDINGS_SVG_QUERY_URL_XXXXXX "http://alpha.vectors.cloudmade.com/8ee2a50541944fb9bcedded5165f09d9/19.921,50.088,19.933,50.082/polygon/%28%22building%22%20IS%20NOT%20NULL%29?zoom=18"
@@ -23,7 +24,7 @@ typedef struct {
 	GArray *polygons; // data == GArray with double x and y values
 } t_buildings3d;
 
-void start_element(GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer user_data, GError **error) {
+void buildings_start_element(GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer user_data, GError **error) {
 	t_buildings3d *result = user_data;
 	const gchar **name_cursor = attribute_names;
 	const gchar **value_cursor = attribute_values;
@@ -82,28 +83,21 @@ void start_element(GMarkupParseContext *context, const gchar *element_name, cons
 	}
 }
 
-void text(GMarkupParseContext *context, const gchar *text, gsize text_len, gpointer user_data, GError **error) {
-	/* Note that "text" is not a regular C string: it is
-	 * not null-terminated. This is the reason for the
-	 * unusual %*s format below.
-	 */
-	//if (current_animal_noise)
-	//  printf("I am a %*s and I go %s. Can you do it?\n", text_len, text, current_animal_noise);
+void buildings_text(GMarkupParseContext *context, const gchar *text, gsize text_len, gpointer user_data, GError **error) {
 }
 
-void end_element(GMarkupParseContext *context, const gchar *element_name, gpointer user_data, GError **error) {
-	//if (current_animal_noise) {
-	//  g_free(current_animal_noise);
-	//        current_animal_noise = NULL;
-	//  }
+void buildings_end_element(GMarkupParseContext *context, const gchar *element_name, gpointer user_data, GError **error) {
 }
 
-void parse_error(GMarkupParseContext *context, GError *error, gpointer user_data) {
-	fprintf(stderr, "parse_error: %s\n", error -> message);
+void buildings_parse_error(GMarkupParseContext *context, GError *error, gpointer user_data) {
+	char buf[300];
+	sprintf(buf, "XML parse error: %s\n", error -> message);
+	fprintf(stderr, "%s", buf);
+	addConsoleLine(buf, 1, 0, 0);
 }
 
 /* The list of what handler does what. */
-static GMarkupParser parser = { start_element, end_element, text, NULL, &parse_error };
+static GMarkupParser parser = { buildings_start_element, buildings_end_element, buildings_text, NULL, &buildings_parse_error };
 
 void buildings3dtest() {
 	char *url, *svg;
@@ -164,4 +158,5 @@ void buildings3dtest() {
 		g_markup_parse_context_free(context);
 		free(svg);
 	}
+	remove(CLOUDMADE_BUILDINGS_TMP_FILE);
 }
