@@ -93,8 +93,7 @@ SDL_Surface* loadTextureFromFile(char *filename, t_tile* tile, SDL_Surface** mas
 
 GLuint createTexture(GLushort * pixels4444, int w, int h, int isTile);
 
-#define MAX_BUF_SIZE 500
-char buf[MAX_BUF_SIZE];
+char strbuf[MAX_BUF_SIZE];
 
 void setQuadTriangleSize(GLfloat w, GLfloat h, GLfloat quad[12]) {
 	quad[3] = w;
@@ -551,9 +550,9 @@ void drawTile_debug(t_tile *tile) {
 	glEnable(GL_TEXTURE_2D);
 
 	//
-	//	sprintf(buf, "%d", tile -> state);
+	//	sprintf(strbuf, "%d", tile -> state);
 	//	glScalef(16.0, 16.0, 16.0);
-	//	drawString(buf, 0.1f, .0, 1.0, TRUE);
+	//	drawString(strbuf, 0.1f, .0, 1.0, TRUE);
 	//	glScalef(.0625, .0625, .0625);
 }
 
@@ -572,17 +571,18 @@ void drawTile(t_tile* tile) {
 		glVertexPointer(3, GL_FLOAT, 0, boxVertices);
 		glDrawArrays(GL_LINE_LOOP, 0, 4);
 		//        if (tile -> errorMessage) {
-		//            sprintf(buf, "Error: %s", tile->errorMessage);
-		//            drawString(buf, 1.0f, .2, .2, TRUE);
+		//            sprintf(strbuf, "Error: %s", tile->errorMessage);
+		//            drawString(strbuf, 1.0f, .2, .2, TRUE);
 		//        }
 	}
 
-	if ((tile -> state == STATE_LOADED) && nowMillis - tile->stateChangeTime < tile->transitionTime) {
-		color = (nowMillis - tile->stateChangeTime) / (float) tile->transitionTime;
+	// TODO tmp
+//	if ((tile -> state == STATE_LOADED) && nowMillis - tile->stateChangeTime < tile->transitionTime) {
+//		color = (nowMillis - tile->stateChangeTime) / (float) tile->transitionTime;
 		//		color = 1.0 - sqrt(sqrt(1.0 - color));
-	} else {
+//	} else {
 		color = 1.0;
-	}
+//	}
 
 	// If there is old tile to display and loaded tile to blend with it use multitexturing for smoother transition.
 	if (tile -> state == STATE_LOADED && color < 1.0 && tile -> oldTiles[0] != NULL) {
@@ -754,11 +754,11 @@ void drawTile(t_tile* tile) {
 				}
 			}
 		}
-		sprintf(buf, "x=%d, y=%d, state=%d, tc=%d", tile->tilex, tile -> tiley, tile -> state, count);
-		drawString(buf, 0.1f, .0, 1.0, TRUE);
+		sprintf(strbuf, "x=%d, y=%d, state=%d, tc=%d", tile->tilex, tile -> tiley, tile -> state, count);
+		drawString(strbuf, 0.1f, .0, 1.0, TRUE);
 		glTranslatef(0, 16, 0);
-		sprintf(buf, "tx=%d otx=%d vis=%d", tile->texture, (tile->oldTiles[0] != NULL ? ((t_tile*) (tile->oldTiles[0]))->texture : -1), tile->visible);
-		drawString(buf, 0.1f, .0, 1.0, TRUE);
+		sprintf(strbuf, "tx=%d otx=%d vis=%d", tile->texture, (tile->oldTiles[0] != NULL ? ((t_tile*) (tile->oldTiles[0]))->texture : -1), tile->visible);
+		drawString(strbuf, 0.1f, .0, 1.0, TRUE);
 		glTranslatef(0, -16, 0);
 	}
 }
@@ -1119,11 +1119,11 @@ void drawGLScene() {
 		glScalef(20, 20, 20);
 		glTranslatef(-150, -20, 0);
 		glEnable(GL_TEXTURE_2D);
-		sprintf(buf, "intZoom:%d, destZoom:%d, zoom:%d", canvas.attractionIntermediateZoom, canvas.attractionDestZoom, canvas.zoom);
-		drawString(buf, .2, .0, 0.5, TRUE);
+		sprintf(strbuf, "intZoom:%d, destZoom:%d, zoom:%d", canvas.attractionIntermediateZoom, canvas.attractionDestZoom, canvas.zoom);
+		drawString(strbuf, .2, .0, 0.5, TRUE);
 		glTranslatef(0, -20, 0);
-		sprintf(buf, "allocatedTiles: %d, dq: %d", allCreatedTiles -> length, downloadQueue -> length);
-		drawString(buf, .2, .0, 0.5, TRUE);
+		sprintf(strbuf, "allocatedTiles: %d, dq: %d", allCreatedTiles -> length, downloadQueue -> length);
+		drawString(strbuf, .2, .0, 0.5, TRUE);
 	}
 
 	glLoadIdentity();
@@ -1188,25 +1188,25 @@ void drawGLScene() {
 	if (options.showCoordinates) {
 		glTranslatef(7, 7, 0);
 		glColor4f(0.1, 0.1, 0.1, 0.6);
-		sprintf(buf, "%04.6f %04.6f", canvas.center.latitude, canvas.center.longitude);
+		sprintf(strbuf, "%04.6f %04.6f", canvas.center.latitude, canvas.center.longitude);
 
-		setQuadStripSize(stringWidth(buf) + 10, 40, quadStripVertices);
+		setQuadStripSize(stringWidth(strbuf) + 10, 40, quadStripVertices);
 		glVertexPointer(3, GL_FLOAT, 0, quadStripVertices);
 		glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
 
 		glTranslatef(7, 5, 0);
-		drawString(buf, 1.0, 1.0, 1.0, FALSE);
+		drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 		glTranslatef(0, 15, 0);
 		double distance = getDistance(&canvas.center, &canvas.currentPos);
 
 		if (distance < 1000) {
-			sprintf(buf, "distance = %.0fm", distance);
+			sprintf(strbuf, "distance = %.0fm", distance);
 		} else if (distance < 100000) {
-			sprintf(buf, "distance = %.2fkm", distance / 1000);
+			sprintf(strbuf, "distance = %.2fkm", distance / 1000);
 		} else {
-			sprintf(buf, "distance = %.0fkm", distance / 1000);
+			sprintf(strbuf, "distance = %.0fkm", distance / 1000);
 		}
-		drawString(buf, 1.0, 1.0, 1.0, FALSE);
+		drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 	}
 
 	frames++;
