@@ -15,6 +15,7 @@
 #include <wchar.h>
 
 #include "main.h"
+#include "geocoding/geocoder.h"
 
 void initInput() {
 	mouse.x = -1;
@@ -79,18 +80,18 @@ void processTextInput(char* text) {
 			i++;
 		}
 
-		if (i < 98) {
+		if (i < SEARCHBAR_MAX_CHARS - 2) {
 			while (i > searchBar.cursorInput) {
 				searchBar.input[i] = searchBar.input[i - 1];
 				i--;
 			}
 		}
-		if (searchBar.cursorInput >= 98) {
-			searchBar.cursorInput = 98;
+		if (searchBar.cursorInput >= SEARCHBAR_MAX_CHARS - 2) {
+			searchBar.cursorInput = SEARCHBAR_MAX_CHARS - 2;
 		}
 
 		searchBar.input[searchBar.cursorInput] = text[0];
-		if (searchBar.cursorInput <= 98) {
+		if (searchBar.cursorInput <= SEARCHBAR_MAX_CHARS - 2) {
 			searchBar.cursorInput++;
 		}
 		computeCursorScreen();
@@ -149,6 +150,23 @@ void processKeyDown(SDL_KeyboardEvent key) {
 				canvas.attractionToPoint = 1;
 			}
 			break;
+		case SDLK_s: {
+			if (key.keysym.mod & KMOD_LSHIFT) {
+				if (options.geocodingProvider > 0) {
+					options.geocodingProvider--;
+				} else {
+					options.geocodingProvider = MAX_GEOCODING_PROVIDERS - 1;
+				}
+			} else {
+				options.geocodingProvider++;
+				if (options.geocodingProvider >= MAX_GEOCODING_PROVIDERS) {
+					options.geocodingProvider = 0;
+				}
+			}
+			sprintf(strbuf, "New search provider: %s\n", geocodingProviderNames[options.geocodingProvider]);
+			addConsoleLine(strbuf, 0, 1.0, 0);
+		}
+			break;
 		case SDLK_n: {
 			GList *provider = tileProviders;
 
@@ -173,8 +191,8 @@ void processKeyDown(SDL_KeyboardEvent key) {
 				provider = provider -> next;
 			}
 
-			sprintf(buf, "New tile provider: %s\n", canvas.provider -> name);
-			addConsoleLine(buf, 0, 1.0, 0);
+			sprintf(strbuf, "New tile provider: %s\n", canvas.provider -> name);
+			addConsoleLine(strbuf, 0, 1.0, 0);
 			recreateTiles();
 		}
 			break;
@@ -186,7 +204,7 @@ void processKeyDown(SDL_KeyboardEvent key) {
 		switch (key.keysym.sym) {
 		case SDLK_RETURN:
 		case SDLK_KP_ENTER:
-			geocode(searchBar.input);
+			processNewSearchQuery(searchBar.input);
 			break;
 		case SDLK_LEFT:
 			if (searchBar.cursorInput > 0) {
