@@ -29,7 +29,7 @@
 
 #include "main.h"
 #include "tile.h"
-#include "network.c"
+#include "network.h"
 #include "texture.h"
 #include "screen.h"
 #include "tileProviders.c"
@@ -43,7 +43,7 @@ LocationGPSDControl *control;
 #include "tileengine.h"
 #include "glcanvas.c"
 #include "accelerometer.c"
-#include "geocoder.c"
+#include "geocoding/geocoder.h"
 #include "buildings3d.c"
 #include "input.c"
 #include "config.c"
@@ -85,8 +85,8 @@ void setQuitFlag() {
 //	SDL_Surface * image = SDL_CreateRGBSurface(SDL_SWSURFACE, SCREEN_WIDTH, SCREEN_HEIGHT, 24, 0x00FF0000, 0x0000FF00, 0x000000FF, 0);
 //	glReadBuffer(GL_FRONT);
 //	glReadPixels(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT, GL_RGB, GL_UNSIGNED_BYTE, image->pixels);
-//	sprintf(buf, "pic-%08l.bmp", nowMillis);
-//	SDL_SaveBMP(image, buf);
+//	sprintf(strbuf, "pic-%08l.bmp", nowMillis);
+//	SDL_SaveBMP(image, strbuf);
 //	SDL_FreeSurface(image);
 //}
 
@@ -159,6 +159,7 @@ int main(int argc, char **argv) {
 			}
 		}
 		processKeyboard();
+		processGeocoding();
 		processAccelerometer();
 		tileEngineUpdateCoordinates();
 		tileEngineUpdateMarkers();
@@ -186,7 +187,7 @@ int main(int argc, char **argv) {
 			lastBatteryRefresh = nowMillis;
 			saveConfig();
 		}
-		if (nowMillis - lastGarbageCollection > 2000 || forceGarbageCollection) /*|| g_queue_get_length(allCreatedTiles) > 4 * TILES_X * TILES_Y)*/{
+		if (nowMillis - lastGarbageCollection > 500 || forceGarbageCollection) /*|| g_queue_get_length(allCreatedTiles) > 4 * TILES_X * TILES_Y)*/{
 			processDeferredDeallocation();
 			lastGarbageCollection = nowMillis;
 			forceGarbageCollection = FALSE;
