@@ -11,10 +11,10 @@
  * Author: Damian Waradzyn
  */
 
-#include "console.h"
+#include "network.h"
 
 extern int downloaded;
-extern char buf[];
+extern char strbuf[];
 
 size_t writeToFileStream(void *ptr, size_t size, size_t nmemb, void *stream) {
     fwrite(ptr, size, nmemb, (FILE *) stream);
@@ -76,8 +76,8 @@ int downloadAndSave(char *url, char *filename) {
     destFile = fopen(filename, "wb");
 
     if (destFile == NULL) {
-        sprintf(buf, "Unable to open file '%s' for writing", filename);
-        addConsoleLine(buf, 1, 0, 0);
+        sprintf(strbuf, "Unable to open file '%s' for writing", filename);
+        addConsoleLine(strbuf, 1, 0, 0);
         return FALSE;
     }
     int result = downloadAndStream(url, destFile, &writeToFileStream);
