@@ -119,7 +119,7 @@ void deallocateTile(t_tile *tile) {
     GLuint texture = tile->texture;
     tile->texture = 0;
     if (texture != 0) {
-        glDeleteTextures(1, &texture);
+        deleteTexture(texture);
     }
     if (ALLOC_DEBUG) {
         fprintf(stderr, "deallocateTile, free pixels4444 %p\n", tile -> pixels4444);
@@ -194,6 +194,7 @@ int downloadThread(void* queue) {
                 fprintf(stderr, "SemWait failed in downloadThread\n");
                 exit(1);
             }
+            SDL_Delay(20);
             tile = (t_tile*) dequeue(queue);
         }
         int mapSize = 1 << tile -> zoom;
