@@ -25,7 +25,7 @@
 #ifdef N900
 #define DOWNLOADING_THREADS 2
 #else
-#define DOWNLOADING_THREADS 8
+#define DOWNLOADING_THREADS 4
 #endif
 extern Canvas canvas;
 UiElement* pressedUiElem;
@@ -165,7 +165,7 @@ void deleteZoomTile(TileCoordinate* tc, int zoomTileIdx, int zoom) {
 				zoomTiles[zoom][zoomTileIdx] -> texture = 0;
 				zoomTiles[zoom][zoomTileIdx] -> state = STATE_GL_TEXTURE_NOT_CREATED;
 				if (!zoomTiles[zoom][zoomTileIdx] -> textureShared) {
-					glDeleteTextures(1, &texture);
+					deleteTexture(texture);
 				}
 				zoomTiles[zoom][zoomTileIdx] -> textureShared = FALSE;
 				zoomTiles[zoom][zoomTileIdx] -> textureUsedTime = 0;
@@ -186,8 +186,10 @@ void createZoomTile(TileCoordinate* tc, int zoomTileIdx, int zoom) {
 			}
 
 			// Limit amount of helper tiles added to queue per second.
-			if (nowMillis - lastZoomHelperTileCreatedMilis < 100) {
-				newTile = FALSE;
+			if (canvas.destScale != 0.0) {
+				if (nowMillis - lastZoomHelperTileCreatedMilis < 200) {
+					newTile = FALSE;
+				}
 			}
 		}
 
@@ -290,7 +292,7 @@ void tileEngine_handleZoomTiles() {
 										if (zoomTiles[k][zoomTileIdx] -> state >= STATE_LOADED) {
 											if (zoomTiles[k][zoomTileIdx] -> texture == 0) {
 												if (texturesCreatedThisFrame >= MAX_TEXTURES_CREATED_PER_FRAME) {
-													break;
+													continue;
 												}
 												zoomTiles[k][zoomTileIdx] -> texture = createTexture(zoomTiles[k][zoomTileIdx] -> pixels4444, TILE_SIZE, TILE_SIZE, TRUE);
 												zoomTiles[k][zoomTileIdx] -> state = STATE_LOADED;
@@ -352,7 +354,7 @@ void initTileEngine() {
 		//        fprintf(stderr, "before SDL_CreateThread\n");
 		downloadThreads[i] = SDL_CreateThread(downloadThread, (void*) downloadQueue);
 		//        fprintf(stderr, "after SDL_CreateThread\n");
-		SDL_Delay(15);
+//		SDL_Delay(15);
 	}
 
 	for (i = 0; i < TILES_X; i++) {
@@ -775,7 +777,7 @@ int isInsideBox(Point* p, GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2) {
 }
 
 GLfloat getMarkerRotation() {
-	return -canvas.rotz - pow(canvas.orientationTransitionLinear/ 160.0, 2.0) * 90.0;
+	return -canvas.rotz - pow(canvas.orientationTransitionLinear/ 160.0, 1.5) * 90.0;
 }
 
 extern Texture searchMarkTexture;
@@ -800,6 +802,9 @@ void checkClickedMarkers() {
 		if (marker -> visible) {
 			if (isInsideBox(&marker -> screenCoordinate, x1 - searchMarkTexture.size / 2, y1 - searchMarkTexture.size / 2, x1 + searchMarkTexture.size / 2, y1 + searchMarkTexture.size / 2)) {
 				setAttractionToPoint(&marker -> geoCodeResult -> centroid);
+				if (marker -> geoCodeResult -> description != NULL) {
+					addConsoleLine((char *) marker -> geoCodeResult -> description, 0, 1, 1);
+				}
 				break;
 			}
 		}
@@ -1523,12 +1528,13 @@ void tileEngine_computeTilesVisibility() {
 				if (tileCoordinateVisibility[i][j] || tileCoordinateVisibility[i + 1][j] || tileCoordinateVisibility[i][j + 1] || tileCoordinateVisibility[i + 1][j + 1]) {
 					if (tiles[i][j][currentTilesIdx] -> state == STATE_GL_TEXTURE_NOT_CREATED && texturesCreatedThisFrame < MAX_TEXTURES_CREATED_PER_FRAME) {
 						tiles[i][j][currentTilesIdx]->texture = createTexture(tiles[i][j][currentTilesIdx] -> pixels4444, TILE_SIZE, TILE_SIZE, TRUE);
-						if (syncLoadedTilesAppearance == TRUE) {
-							tiles[i][j][currentTilesIdx] -> state = STATE_LOADED_SYNC_WAIT;
-						} else {
+						// TODO tmp
+//						if (syncLoadedTilesAppearance == TRUE) {
+//							tiles[i][j][currentTilesIdx] -> state = STATE_LOADED_SYNC_WAIT;
+//						} else {
 							tiles[i][j][currentTilesIdx] -> state = STATE_LOADED;
 							tiles[i][j][currentTilesIdx] ->stateChangeTime = 0;
-						}
+//						}
 						texturesCreatedThisFrame++;
 					}
 					tiles[i][j][currentTilesIdx] -> visible = TRUE;
@@ -1538,7 +1544,7 @@ void tileEngine_computeTilesVisibility() {
 						GLuint texture = tiles[i][j][currentTilesIdx] -> texture;
 						tiles[i][j][currentTilesIdx] -> texture = 0;
 						tiles[i][j][currentTilesIdx] -> state = STATE_GL_TEXTURE_NOT_CREATED;
-						glDeleteTextures(1, &texture);
+						deleteTexture(texture);
 					}
 				}
 			}
