@@ -317,8 +317,8 @@ void drawZoomBar() {
 
 	GLfloat x = canvas.orientationTransitionLinear < 80 ? zoomKnot -> x : SCREEN_HEIGHT - zoomKnot -> y - 64;
 	glTranslatef(x, -180, 0);
-	sprintf(buf, "zoom = %d", getKnotDestZoom());
-	drawStringAlpha(buf, canvas.zoomBarAlpha, canvas.zoomBarAlpha, canvas.zoomBarAlpha, 1.0, FALSE, GL_ZERO, GL_ONE_MINUS_SRC_COLOR);
+	sprintf(strbuf, "zoom = %d", getKnotDestZoom());
+	drawStringAlpha(strbuf, canvas.zoomBarAlpha, canvas.zoomBarAlpha, canvas.zoomBarAlpha, 1.0, FALSE, GL_ZERO, GL_ONE_MINUS_SRC_COLOR);
 	glTranslatef(-x, 180, 0);
 
 	if (canvas.orientationTransitionLinear < 80) {
@@ -516,11 +516,11 @@ void drawSatelliteBars(GLfloat barHeight, GLfloat barWidth, GLfloat separation)
 				satelliteBars[i * 18 + 17] = 0.0;
 
 				// TODO - this should be optimized and passed to opengl in one call.
-				sprintf(buf, "%d", sat -> prn);
-				x += 5 - stringWidth(buf) / 2;
+				sprintf(strbuf, "%d", sat -> prn);
+				x += 5 - stringWidth(strbuf) / 2;
 
 				glTranslatef(x, barHeight, 0);
-				drawString(buf, .7 + .3 * (i % 2), .7 + .3 * (i % 2), .7 + .3 * (i % 2), TRUE);
+				drawString(strbuf, .7 + .3 * (i % 2), .7 + .3 * (i % 2), .7 + .3 * (i % 2), TRUE);
 				glTranslatef(-x, -barHeight, 0);
 
 			} else {
@@ -616,30 +616,30 @@ void drawStatusBar(Orientation orientation) {
 	if (consoleLines != NULL && consoleLines -> length > 0) {
 		drawConsoleLine(g_queue_peek_tail(consoleLines));
 	} else {
-		sprintf(buf, "D/l: %.2f kb", downloaded / 1024.0);
-		drawString(buf, 1.0, 1.0, 1.0, FALSE);
+		sprintf(strbuf, "D/l: %.2f kb", downloaded / 1024.0);
+		drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 	}
 
 	glTranslatef(0, 20, 0);
 #ifdef N900
 	switch (device -> fix -> mode) {
 		case LOCATION_GPS_DEVICE_MODE_2D:
-		sprintf(buf, "GPS fix: 2D");
+		sprintf(strbuf, "GPS fix: 2D");
 		break;
 		case LOCATION_GPS_DEVICE_MODE_3D:
-		sprintf(buf, "GPS fix: 3D");
+		sprintf(strbuf, "GPS fix: 3D");
 		break;
 		case LOCATION_GPS_DEVICE_MODE_NOT_SEEN:
-		sprintf(buf, "GPS fix: not seen");
+		sprintf(strbuf, "GPS fix: not seen");
 		break;
 		case LOCATION_GPS_DEVICE_MODE_NO_FIX:
-		sprintf(buf, "GPS fix: no fix");
+		sprintf(strbuf, "GPS fix: no fix");
 		break;
 	}
 #else
-	sprintf(buf, "No GPS");
+	sprintf(strbuf, "No GPS");
 #endif
-	drawString(buf, 1.0, 1.0, 1.0, FALSE);
+	drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 	if (orientation == LANDSCAPE) {
 		glTranslatef(140, -20, 0);
 	} else {
@@ -656,23 +656,23 @@ void drawStatusBar(Orientation orientation) {
 		if (FALSE) {
 #endif
 #ifdef N900
-			sprintf(buf, "Altitude: %.2f m", device -> fix -> altitude);
+			sprintf(strbuf, "Altitude: %.2f m", device -> fix -> altitude);
 #endif
 		} else {
-			sprintf(buf, "Altitude: ---");
+			sprintf(strbuf, "Altitude: ---");
 		}
-		drawString(buf, 1.0, 1.0, 1.0, FALSE);
+		drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 	}
 	glTranslatef(0, 20, 0);
 
-	sprintf(buf, "Speed: ---");
+	sprintf(strbuf, "Speed: ---");
 #ifdef N900
 	if (device -> satellites_in_use > 0 && device -> fix -> fields | LOCATION_GPS_DEVICE_SPEED_SET && !isnan(device -> fix -> speed)) {
-		sprintf(buf, "Speed: %.2f km/h", device -> fix -> speed);
+		sprintf(strbuf, "Speed: %.2f km/h", device -> fix -> speed);
 	}
 #endif
 
-	drawString(buf, 1.0, 1.0, 1.0, FALSE);
+	drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 
 	if (orientation == LANDSCAPE) {
 		glTranslatef(350, -20, 0);
@@ -680,8 +680,8 @@ void drawStatusBar(Orientation orientation) {
 		glTranslatef(-120, 20, 0);
 	}
 
-	sprintf(buf, "FPS: %.1f", fps);
-	drawString(buf, 1.0, 1.0, 1.0, FALSE);
+	sprintf(strbuf, "FPS: %.1f", fps);
+	drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 
 	if (orientation == LANDSCAPE) {
 		glTranslatef(0, 20, 0);
@@ -689,8 +689,8 @@ void drawStatusBar(Orientation orientation) {
 		glTranslatef(120, 0, 0);
 	}
 
-	sprintf(buf, "Battery: %d%%", batteryPercentage);
-	drawString(buf, 1.0, 1.0, 1.0, FALSE);
+	sprintf(strbuf, "Battery: %d%%", batteryPercentage);
+	drawString(strbuf, 1.0, 1.0, 1.0, FALSE);
 
 	if (orientation == LANDSCAPE) {
 		glTranslatef(-230, -23, 0);
